#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2024  SVA System Vertrieb Alexander GmbH
#                       by leon.buhleier@sva.de

from cmk.agent_based.v2 import (
    CheckPlugin,
    AgentSection,
    CheckResult,
    Result,
    State,
    check_levels,
    LevelsT,
)

from cmk_addons.plugins.emcunity.lib.utils import *

from typing import TypedDict # type: ignore


class Params(TypedDict):
    eol: LevelsT[int]


agent_section_emcunity_disk = AgentSection(
    name="emcunity_disk",
    parse_function=parse_emcunity_generic,
)


def check_emcunity_disk(item: str, params: dict, section: dict[str, dict[str, str]]) -> CheckResult:
    for _id, disk in section.items():
        if disk.get("Name") == item:
            yield from check_health(disk.get("Health state"), disk.get('Health details'))

            if disk.get('Days remaining to EOL') != "":
                yield Result(
                    state=State.OK,
                    summary=f"Model: {disk.get('Model')}, Type: {disk.get('Type')}, Pool: {disk.get('Pool')}",
                )
                yield from check_levels(
                    value=int(disk.get('Days remaining to EOL')),
                    label="EOL in",
                    levels_lower=params.get("eol"),
                    metric_name="emcunity_eol_in_days",
                )

check_plugin_emcunity_disk = CheckPlugin(
    name="emcunity_disk",
    service_name="Disk %s",
    discovery_function=discover_emcunity_generic,
    check_function=check_emcunity_disk,
    check_ruleset_name="emcunity_disk",
    check_default_parameters=Params(
        eol=("fixed", (60, 30)),
    ),
)