#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2024  SVA System Vertrieb Alexander GmbH
#                       by leon.buhleier@sva.de

from cmk.agent_based.v2 import (
    CheckPlugin,
    AgentSection,
    CheckResult,
    Result,
    State,
)

from cmk_addons.plugins.emcunity.lib.utils import *


agent_section_emcunity_sp = AgentSection(
    name="emcunity_sp",
    parse_function=parse_emcunity_generic,
)


def check_emcunity_sp(item: str, section: dict[str, dict[str, str]]) -> CheckResult:
    for _id, sp in section.items():
        if sp.get("Name") == item:
            yield from check_health(sp.get("Health state"), sp.get('Health details'))
            yield Result(
                state=State.OK,
                summary=f"Mode: {sp.get("Mode")}, Memory Size: {sp.get("Memory size").strip(')').split("(")[-1]}",
            )

check_plugin_emcunity_sp = CheckPlugin(
    name="emcunity_sp",
    service_name="Storage Processor %s",
    discovery_function=discover_emcunity_generic,
    check_function=check_emcunity_sp,
)