#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-ofvmfset: 4 -*-

# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2024  SVA System Vertrieb Alexander GmbH
#                       by leon.buhleier@sva.de

from cmk.agent_based.v2 import (
    CheckPlugin,
    AgentSection,
    get_value_store
)

from cmk_addons.plugins.emcunity.lib.utils import *

from cmk.plugins.lib.df import *

import time


agent_section_emcunity_vmfs = AgentSection(
    name="emcunity_vmfs",
    parse_function=parse_emcunity_generic,
)


def _render_emcuntiy_fs_size(size: str) -> float:
    size = size.split(" ")[0]
    size = float(size) / 1024.0**2
    return size

def check_emcunity_vmfs(item: str, params: dict, section: dict[str, dict[str, str]]):
    for _id, vmfs in section.items():
        if vmfs.get("Name") == item:
            yield from check_health(vmfs.get("Health state"), vmfs.get('Health details'))
            
            fs_size = _render_emcuntiy_fs_size(vmfs.get("Size"))
            fs_used = _render_emcuntiy_fs_size(vmfs.get("Current allocation"))
            fs_free = fs_size - fs_used
            yield from df_check_filesystem_single(
                filesystem_size=fs_size,
                free_space=fs_free,
                inodes_avail=None,
                inodes_total=None,
                mountpoint=item,
                params=params,
                reserved_space=fs_used,
                this_time=time.time(),
                value_store=get_value_store(),
            )

check_plugin_emcunity_vmfs = CheckPlugin(
    name="emcunity_vmfs",
    service_name="VMFS %s",
    discovery_function=discover_emcunity_generic,
    check_function=check_emcunity_vmfs,
    check_ruleset_name="filesystem",
    check_default_parameters=EMCUNITY_DEFAULT_PARAMS,
)