#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2024  SVA System Vertrieb Alexander GmbH
#                       by leon.buhleier@sva.de

from cmk.rulesets.v1 import (
    Title,
)

from cmk.rulesets.v1.form_specs import (
    Dictionary,
    DictElement,
    String,
    Password,
    migrate_to_password,
)

from cmk.rulesets.v1.rule_specs import (
    SpecialAgent,
    Topic,
)

from cmk.rulesets.v1.form_specs.validators import LengthInRange

def _form_agent_emcunity() -> Dictionary:
    return Dictionary(
        title=Title("Check state of EMC Unity"),
        elements={
            "username": DictElement(
                parameter_form=String(
                    title=Title("Username"),
                    custom_validate=[
                        LengthInRange(min_value=1),
                    ],
                ),
                required=True,
            ),
            "password": DictElement(
                parameter_form=Password(
                    title=Title("Password"),
                    custom_validate=[
                        LengthInRange(min_value=1),
                    ],
                    migrate=migrate_to_password,
                ),
                required=True,
            ),
        },
    )

rule_spec_emcuntiy_agent = SpecialAgent(
    title=Title("EMC Unity"),
    topic=Topic.STORAGE,
    name="emcunity",
    parameter_form=_form_agent_emcunity,
)